orthographic

Function orthographic 

pub fn orthographic(
    left: f32,
    right: f32,
    bottom: f32,
    top: f32,
    near: f32,
    far: f32,
) -> Mat4
Creates an orthographic projection matrix for use with Vulkan.

Expects a right-handed Y-up view space input. Outputs NDC with Z in [0, 1] and Y-down.

Panics

Will panic if left is equal to right, if bottom is equal to top, or if near is equal to far when glam_assert is enabled.